@@ -1,15 +1,10 @@
-use MooseX::Declare;
+package Data::DPath::Point;
 
 use 5.010;
+use strict;
+use warnings;
 
-class Data::DPath::Point {
-        has parent => ( is  => "rw", default => sub { undef } );
-        has ref    => ( is  => "rw", default => sub { undef } );
-        has attrs  => ( is  => "rw", default => sub { {}    } );
-}
-
-# help the CPAN indexer
-package Data::DPath::Point;
+use Object::Tiny::RW 'parent', 'ref', 'attrs';
 
 1;
 
@@ -25,4 +20,18 @@ references in the data structure, i.e., lists of such B<Point>s. The
 remaining B<Point>s at the end just need to be dereferenced and form
 the result.
 
+=head1 INTERNAL METHODS
+
+=head2 parent
+
+Attribute / accessor.
+
+=head2 ref
+
+Attribute / accessor.
+
+=head2 attrs
+
+Attribute / accessor.
+
 =cut
